==> notebookvisu-0.1.1.tar.gz: notebookvisu-0.1.1/src/toc-dashboard/generator/index.ts <==
import { Cell, CodeCell, CodeCellModel, MarkdownCell } from '@jupyterlab/cells';
import { INotebookTracker, NotebookPanel } from '@jupyterlab/notebook';
import { ITranslator, nullTranslator } from '@jupyterlab/translation';
import { IRenderMime } from '@jupyterlab/rendermime';
import { INotebookHeading } from '../../utils/headings';
import { OptionsManager } from './options_manager';
import { render } from './render';
import { toolbar } from './toolbar_generator';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { TocDashboardPanel } from '../tocDashboardPanel';
import { IGenerator } from '../../utils/interfaces';
import {
  getCodeCellHeading,
  getLastHeadingLevel,
  appendHeading,
  getMarkdownHeadings,
  appendMarkdownHeading,
  getRenderedHTMLHeadings,
  MARKDOWN_HEADING_COLLAPSED,
  UNSYNC_MARKDOWN_HEADING_COLLAPSED
} from './utils';

function createNotebookGenerator(
  tracker: INotebookTracker,
  widget: TocDashboardPanel,
  sanitizer: IRenderMime.ISanitizer,
  translator?: ITranslator,
  settings?: ISettingRegistry.ISettings
): IGenerator {
  let numberingH1 = true;
  let syncCollapseState = false;
  if (settings) {
    numberingH1 = settings.composite.numberingH1 as boolean;
    syncCollapseState = settings.composite.syncCollapseState as boolean;
  }
  const options = new OptionsManager(widget, tracker, {
    numbering: false,
    numberingH1: numberingH1,
    syncCollapseState: syncCollapseState,
    sanitizer: sanitizer,
    translator: translator || nullTranslator
  });
  if (settings) {
    settings.changed.connect(() => {
      options.numberingH1 = settings.composite.numberingH1 as boolean;
      options.syncCollapseState = settings.composite
        .syncCollapseState as boolean;
    });
  }

  tracker.activeCellChanged.connect(() => {
    widget.update();
  });
  return {
    tracker,
    options: options,
    toolbarGenerator: generateToolbar,
    itemRenderer: renderItem,
    generate: generate,
    collapseChanged: options.collapseChanged
  };

  function generateToolbar() {
    return toolbar(options, tracker);
  }

  function renderItem(
    item: INotebookHeading,
    headings: INotebookHeading[] = []
  ) {
    return render(options, tracker, item, headings);
  }

  function generate(panel: NotebookPanel): INotebookHeading[] {
    let headings: INotebookHeading[] = [];
    let collapseLevel = -1;
    let dict = {};

    // initialize a variable for keeping track of the previous heading:
    let prev: INotebookHeading | null = null;

    // generate headings by iterating through all notebook cells...
    for (let i = 0; i < panel.content.widgets.length; i++) {
      let cell: Cell = panel.content.widgets[i];
      let model = cell.model;
      let cellCollapseMetadata = options.syncCollapseState
        ? MARKDOWN_HEADING_COLLAPSED
        : UNSYNC_MARKDOWN_HEADING_COLLAPSED;
      let collapsed = model.metadata[cellCollapseMetadata] as boolean;
      collapsed = collapsed || false;

      if (model.type === 'code') {
        if (!widget || (widget && options.showCode)) {
          const onClick = (line: number) => {
            return () => {
              panel.content.activeCellIndex = i;
              cell.node.scrollIntoView();
            };
          };
          let count = (cell as CodeCell).model.executionCount as number | null;
          let executionCount = count !== null ? '[' + count + ']: ' : '[ ]: ';
          let heading = getCodeCellHeading(
            (model as CodeCellModel).sharedModel.source,
            onClick,
            executionCount,
            getLastHeadingLevel(headings),
            cell,
            i
          );
          [headings, prev] = appendHeading(
            headings,
            heading,
            prev,
            collapseLevel
          );
        }

        continue;
      }
      if (model.type === 'markdown') {
        let mcell = cell as MarkdownCell;
        let heading: INotebookHeading | undefined;
        let lastLevel = getLastHeadingLevel(headings);

        // if the cell is rendered, generate the ToC items from the HTML...
        if (mcell.rendered && !mcell.inputHidden) {
          const onClick = (el: Element) => {
            return () => {
              if (!mcell.rendered) {
                panel.content.activeCellIndex = i;
                el.scrollIntoView();
              } else {
                panel.content.mode = 'command';
                cell.node.scrollIntoView();
                panel.content.activeCellIndex = i;
              }
            };
          };
          const htmlHeadings = getRenderedHTMLHeadings(
            cell.node,
            onClick,
            sanitizer,
            dict,
            lastLevel,
            options.numbering,
            options.numberingH1,
            cell,
            i
          );
          for (heading of htmlHeadings) {
            [headings, prev, collapseLevel] = appendMarkdownHeading(
              heading,
              headings,
              prev,
              collapseLevel,
              collapsed,
              options.showMarkdown
            );
          }
          // if not rendered, generate ToC items from the cell text...
        } else {
          const onClick = (line: number) => {
            return () => {
              panel.content.activeCellIndex = i;
              cell.node.scrollIntoView();
            };
          };
          const markdownHeadings = getMarkdownHeadings(
            model.sharedModel.source,
            onClick,
            dict,
            lastLevel,
            cell,
            i
          );
          for (heading of markdownHeadings) {
            [headings, prev, collapseLevel] = appendMarkdownHeading(
              heading,
              headings,
              prev,
              collapseLevel,
              collapsed,
              options.showMarkdown
            );
          }
        }
      }
    }
    return headings;
  }
}

export { createNotebookGenerator };

==> notebookvisu-0.2.0.tar.gz: notebookvisu-0.2.0/src/toc-dashboard/generator/index.ts <==
import { Cell, CodeCell, CodeCellModel, MarkdownCell } from '@jupyterlab/cells';
import { INotebookTracker, NotebookPanel } from '@jupyterlab/notebook';
import { ITranslator, nullTranslator } from '@jupyterlab/translation';
import { IRenderMime } from '@jupyterlab/rendermime';
import { INotebookHeading } from '../../utils/headings';
import { OptionsManager } from './options_manager';
import { render } from './render';
import { toolbar } from './toolbar_generator';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { TocDashboardPanel } from '../tocDashboardPanel';
import { IGenerator } from '../../utils/interfaces';
import {
  getCodeCellHeading,
  getLastHeadingLevel,
  appendHeading,
  getMarkdownHeadings,
  appendMarkdownHeading,
  getRenderedHTMLHeadings,
  MARKDOWN_HEADING_COLLAPSED,
  UNSYNC_MARKDOWN_HEADING_COLLAPSED
} from './utils';

function createNotebookGenerator(
  tracker: INotebookTracker,
  widget: TocDashboardPanel,
  sanitizer: IRenderMime.ISanitizer,
  translator?: ITranslator,
  settings?: ISettingRegistry.ISettings
): IGenerator {
  let numberingH1 = true;
  let syncCollapseState = false;
  if (settings) {
    numberingH1 = settings.composite.numberingH1 as boolean;
    syncCollapseState = settings.composite.syncCollapseState as boolean;
  }
  const options = new OptionsManager(widget, tracker, {
    numbering: false,
    numberingH1: numberingH1,
    syncCollapseState: syncCollapseState,
    sanitizer: sanitizer,
    translator: translator || nullTranslator
  });
  if (settings) {
    settings.changed.connect(() => {
      options.numberingH1 = settings.composite.numberingH1 as boolean;
      options.syncCollapseState = settings.composite
        .syncCollapseState as boolean;
    });
  }

  tracker.activeCellChanged.connect(() => {
    widget.update();
  });
  return {
    tracker,
    options: options,
    toolbarGenerator: generateToolbar,
    itemRenderer: renderItem,
    generate: generate,
    collapseChanged: options.collapseChanged
  };

  function generateToolbar() {
    return toolbar(options, tracker);
  }

  function renderItem(
    item: INotebookHeading,
    headings: INotebookHeading[] = []
  ) {
    return render(options, tracker, item, headings);
  }

  function generate(panel: NotebookPanel): INotebookHeading[] {
    let headings: INotebookHeading[] = [];
    let collapseLevel = -1;
    const dict = {};

    // initialize a variable for keeping track of the previous heading:
    let prev: INotebookHeading | null = null;

    // generate headings by iterating through all notebook cells...
    for (let i = 0; i < panel.content.widgets.length; i++) {
      const cell: Cell = panel.content.widgets[i];
      const model = cell.model;
      const cellCollapseMetadata = options.syncCollapseState
        ? MARKDOWN_HEADING_COLLAPSED
        : UNSYNC_MARKDOWN_HEADING_COLLAPSED;
      let collapsed = model.metadata[cellCollapseMetadata] as boolean;
      collapsed = collapsed || false;

      if (model.type === 'code') {
        if (!widget || (widget && options.showCode)) {
          const onClick = (line: number) => {
            return () => {
              panel.content.activeCellIndex = i;
              cell.node.scrollIntoView();
            };
          };
          const count = (cell as CodeCell).model.executionCount as
            | number
            | null;
          const executionCount = count !== null ? '[' + count + ']: ' : '[ ]: ';
          const heading = getCodeCellHeading(
            (model as CodeCellModel).sharedModel.source,
            onClick,
            executionCount,
            getLastHeadingLevel(headings),
            cell,
            i
          );
          [headings, prev] = appendHeading(
            headings,
            heading,
            prev,
            collapseLevel
          );
        }

        continue;
      }
      if (model.type === 'markdown') {
        const mcell = cell as MarkdownCell;
        let heading: INotebookHeading | undefined;
        const lastLevel = getLastHeadingLevel(headings);

        // if the cell is rendered, generate the ToC items from the HTML...
        if (mcell.rendered && !mcell.inputHidden) {
          const onClick = (el: Element) => {
            return () => {
              if (!mcell.rendered) {
                panel.content.activeCellIndex = i;
                el.scrollIntoView();
              } else {
                panel.content.mode = 'command';
                cell.node.scrollIntoView();
                panel.content.activeCellIndex = i;
              }
            };
          };
          const htmlHeadings = getRenderedHTMLHeadings(
            cell.node,
            onClick,
            sanitizer,
            dict,
            lastLevel,
            options.numbering,
            options.numberingH1,
            cell,
            i
          );
          for (heading of htmlHeadings) {
            [headings, prev, collapseLevel] = appendMarkdownHeading(
              heading,
              headings,
              prev,
              collapseLevel,
              collapsed,
              options.showMarkdown
            );
          }
          // if not rendered, generate ToC items from the cell text...
        } else {
          const onClick = (line: number) => {
            return () => {
              panel.content.activeCellIndex = i;
              cell.node.scrollIntoView();
            };
          };
          const markdownHeadings = getMarkdownHeadings(
            model.sharedModel.source,
            onClick,
            dict,
            lastLevel,
            cell,
            i
          );
          for (heading of markdownHeadings) {
            [headings, prev, collapseLevel] = appendMarkdownHeading(
              heading,
              headings,
              prev,
              collapseLevel,
              collapsed,
              options.showMarkdown
            );
          }
        }
      }
    }
    return headings;
  }
}

export { createNotebookGenerator };
